import { router } from '../../modules/router.ts';
import { Route } from '@abearxiong/router';
import { RouterCodeModel, RouterCode } from '../../models/code.ts';

enum CodeStatus {
  success = 0,
  fail = 1,
}

export type CodeManager = {
  fn?: any;
  status?: CodeStatus;
  errorMsg?: string;
} & Partial<RouterCode>;
const codeDemoRun = `async function run(ctx) {
  ctx.body = 'test js';
  return ctx;
}`;
export const load = async function () {
  const codes = await RouterCodeModel.findAll();
  const codeManager: CodeManager[] = codes.map((item) => {
    const { path, key, id, code, project } = item.toJSON();
    console.log('item', item, 'code', item.code);
    try {
      const fn: any = new Function(
        'ctx',
        `
      ${code}
      return run(ctx);
    `,
      );
      // run code
      const codeRunRoute = new Route(path, key, { id });
      codeRunRoute.run = fn;
      router.add(codeRunRoute);
      return {
        path,
        key,
        id,
        project,
        fn,
        status: CodeStatus.success,
      };
    } catch (e) {
      console.error('error id:', id, '\n', e);
      return {
        path,
        key,
        id,
        project,
        status: CodeStatus.fail,
        errorMsg: e.message.toString(),
      };
    }
  });
  return codeManager;
};
